@@ -22,7 +22,7 @@ class TypedDictDummy(TypedDict):
     pass
 
 
-def convert_typed_dict(function_annotations: Dict, params: Dict) -> Dict:
+def convert_typed_dict(function_annotations: Dict, params: Dict) -> Dict:  # noqa: C901
     for arg_name, arg_type in function_annotations.items():
         if arg_name not in params or params[arg_name] is None:
             continue
@@ -548,6 +548,21 @@ class ScreenshotFileTypes(Enum):
     jpeg = auto()
 
 
+class ScreenshotReturnType(Enum):
+    """Enum that defines what `Take Screenshot` keyword returns.
+
+    - ``path`` returns the path to the screenshot file as ``pathlib.Path`` object.
+    - ``path_string`` returns the path to the screenshot file as string.
+    - ``bytes`` returns the screenshot itself as bytes.
+    - ``base64`` returns the screenshot itself as base64 encoded string.
+    """
+
+    path = auto()
+    path_string = auto()
+    bytes = auto()
+    base64 = auto()
+
+
 class PageLoadStates(Enum):
     """Enum that defines available page load states."""
 
