@@ -14,10 +14,13 @@
 
 import contextlib
 import inspect
+import os
 import socket
+import subprocess
+from os import PathLike
 from typing import Any, Tuple
 
-from robot.libraries.BuiltIn import BuiltIn  # type: ignore
+from robot.libraries.BuiltIn import BuiltIn
 
 get_variable_value = BuiltIn().get_variable_value
 
@@ -29,6 +32,38 @@ def find_free_port() -> int:
         return s.getsockname()[1]
 
 
+def spawn_node_process(output_dir: PathLike) -> Tuple[subprocess.Popen, str]:
+    """
+    Spawn an rfbrowser node process, that can be shared between library instances.
+
+    Usage example:
+
+    rc = 1
+    background_process, port = spawn_node_process(ATEST_OUTPUT / "playwright-log.txt")
+    try:
+        os.environ["ROBOT_FRAMEWORK_BROWSER_NODE_PORT"] = port
+        rc = _run_pabot(args)
+    finally:
+        background_process.kill()
+
+
+    """
+    logfile = open(output_dir, "w")
+    os.environ["DEBUG"] = "pw:api"
+    os.environ["PLAYWRIGHT_BROWSERS_PATH"] = "0"
+    port = str(find_free_port())
+    process = subprocess.Popen(
+        [
+            "node",
+            "Browser/wrapper/index.js",
+            port,
+        ],
+        stdout=logfile,
+        stderr=subprocess.STDOUT,
+    )
+    return process, port
+
+
 def is_same_keyword(first: str, second: str) -> bool:
     if isinstance(first, str) and isinstance(second, str):
         return get_normalized_keyword(first) == get_normalized_keyword(second)
@@ -37,7 +72,7 @@ def is_same_keyword(first: str, second: str) -> bool:
 
 
 def get_normalized_keyword(keyword: str) -> str:
-    return keyword.lower().replace(" ", "").replace("_", "")
+    return keyword.lower().replace(" ", "_")
 
 
 def keyword(name: Any = None, tags: Tuple = (), types: Tuple = ()):
